{ config, pkgs, ... }:

{
  imports =
    [
      ./common.nix
      ./large-sw.nix
      ./uefi.nix
      ./fstrim.nix
    ];

  environment.etc."lvm/lvm.conf".text = ''
    devices {
      issue_discards = 1
    }
  '';
  boot.initrd.luks.devices = [
    {
      name = "sda2_crypt";
      device = "/dev/disk/by-uuid/a7482f34-1d7b-4181-9f3c-f6bbbdb8679d";
      preLVM = true;
      allowDiscards = true;
    }
  ];

  services.xserver = {
    libinput.enable = true;
    config = ''
      Section "InputClass"
        Identifier "touchpad"
        Driver "libinput"
        MatchDevicePath "/dev/input/event*"
        MatchIsPointer "true"
      EndSection
    '';

    videoDrivers = [ "modesetting" ];
    useGlamor = true;
  };
  programs.light.enable = true;

  services.tlp.enable = true;

  networking.hostName = "theba"; # Define your hostname.
  networking.hostId = "b29b900f";

  # services.colord.enable = true;

  systemd.services.ModemManager.enable = true;

  hardware.opengl.extraPackages = [ pkgs.vaapiIntel ];

  nixpkgs.config.packageOverrides = pkgs: rec {
  };

  environment.systemPackages = with pkgs; [
    unison
  ];

  virtualisation.docker = {
    enable = true;
    storageDriver = "overlay2";
  };
  users.extraUsers.gebner.extraGroups = [ "docker" ];

  virtualisation.virtualbox.host.enable = true;

  # boot.kernelPackages = pkgs.lib.mkOverride 10 pkgs.linuxPackages;

  time.timeZone = pkgs.lib.mkOverride 10 "US/Eastern";

}
